@@ -8,7 +8,7 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model;
-$Config::Model::VERSION = '2.065';
+$Config::Model::VERSION = '2.066';
 use Mouse;
 use Mouse::Util::TypeConstraints;
 use MouseX::StrictConstructor;
@@ -199,7 +199,7 @@ sub instance {
 
 sub instance_names {
     my $self = shift;
-    return keys %{ $self->instances };
+    return sort keys %{ $self->instances };
 }
 
 @level = qw/hidden normal important/;
@@ -423,7 +423,7 @@ sub normalize_class_parameters {
     Config::Model::Exception::ModelDeclaration->throw(
               error => "create class $config_class_name: unexpected "
             . "parameters '"
-            . join( ', ', keys %$normalized_model ) . "' "
+            . join( ', ', sort keys %$normalized_model ) . "' "
             . "Expected '"
             . join( "', '", @legal_params_to_move, @other_legal_params )
             . "'" )
@@ -1024,7 +1024,7 @@ sub include_one_class {
             my $msg =
                   "Unknown element for 'include_after': "
                 . "$include_after, expected "
-                . join( ' ', keys %elt_idx );
+                . join( ' ', sort keys %elt_idx );
             Config::Model::Exception::ModelDeclaration->throw( error => $msg );
         }
 
@@ -1321,10 +1321,10 @@ sub get_migrate_doc {
     else                     { $mform = "'C<$mform>' " }
 
     my $mdoc = "Note: $elt_name $desc ${mform}and with "
-        . join( ", ", map { qq!\$$_ => "C<$mv->{$_}>"! } keys %$mv );
+        . join( ", ", map { qq!\$$_ => "C<$mv->{$_}>"! } sort keys %$mv );
     if ( my $rep = $migr->{replace} ) {
         $mdoc .=
-            ' and ' . join( ", ", map { qq!'C<\$replace{$_}>' => "C<$rep->{$_}>"! } keys %$rep );
+            ' and ' . join( ", ", map { qq!'C<\$replace{$_}>' => "C<$rep->{$_}>"! } sort keys %$rep );
     }
 
     return ( $mdoc, '' );
@@ -1391,7 +1391,7 @@ sub generate_doc {
     my @wrote;
 
     if ( defined $dir and $dir ) {
-        foreach my $class_name ( keys %$res ) {
+        foreach my $class_name ( sort keys %$res ) {
             my $file = $class_name;
             $file =~ s!::!/!g;
             my $pl_file  = $dir . "/$file.pl";
@@ -1418,7 +1418,7 @@ sub generate_doc {
         }
     }
     else {
-        foreach my $class_name ( keys %$res ) {
+        foreach my $class_name ( sort keys %$res ) {
             print "########## $class_name ############ \n\n";
             print $res->{$class_name};
         }
@@ -1556,7 +1556,7 @@ Config::Model - Create tools to validate, migrate and edit configuration files
 
 =head1 VERSION
 
-version 2.065
+version 2.066
 
 =head1 SYNOPSIS
 
@@ -2262,8 +2262,9 @@ Generate POD document for configuration class.
 
 =head2 generate_doc ( top_class_name , [ directory ] )
 
-Generate POD document for configuration class top_class_name
-and write them on STDOUT or in specified directory.
+Generate POD document for configuration class top_class_name and all
+classes used by top_class_name, and write them on STDOUT or in
+specified directory.
 
 Returns a list of written file names.
 
