@@ -8,7 +8,7 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Instance;
-$Config::Model::Instance::VERSION = '2.065';
+$Config::Model::Instance::VERSION = '2.066';
 #use Scalar::Util qw(weaken) ;
 
 use 5.10.1;
@@ -160,8 +160,20 @@ sub has_warning {
 }
 
 has on_change_cb => (
-    is  => 'rw',
-    isa => 'Maybe[CodeRef]',
+    is  => 'ro',
+    traits    => ['Code'],
+    isa       => 'CodeRef',
+    default   => sub { sub { } },
+);
+
+has on_message_cb => (
+    traits    => ['Code'],
+    is        => 'ro',
+    isa       => 'CodeRef',
+    default   => sub { sub { say @_; } },
+    handles   => {
+        show_message => 'execute',
+    },
 );
 
 # initial_load mode: when data is loaded the first time
@@ -381,8 +393,7 @@ sub notify_change {
         $change_logger->debug( "in instance ", $self->name, ' for path ', $args{path} );
     }
     $self->add_change( \%args );
-    my $cb = $self->on_change_cb;
-    $cb->(@_) if $cb;
+    $self->on_change_cb->(@_);
 }
 
 sub list_changes {
@@ -485,7 +496,7 @@ Config::Model::Instance - Instance of configuration tree
 
 =head1 VERSION
 
-version 2.065
+version 2.066
 
 =head1 SYNOPSIS
 
@@ -560,6 +571,11 @@ configuration tree.
 Call back this function whenever C<notify_change> is called. Called with
 arguments: C<< name => <root node element name>, index => <index_value> >>
 
+=item on_message_cb
+
+Call back this function when L<show_message> is called. By default,
+messages will be displayed on STDOUT.
+
 =item error_paths
 
 Returns a list of tree items that currently have an error.
@@ -591,6 +607,11 @@ Returns the root object of the configuration tree.
 
 Returns how to check read files.
 
+=head2 show_message( string )
+
+Display the message on STDOUT unless a custom function was passed to
+C<on_message_cb> parameter.
+
 =head2 reset_config
 
 Destroy current configuration tree (with data) and returns a new tree with
